@@ -9,7 +9,9 @@ with_mock_dir("table1", {
     skip_on_cran()
     skip_on_ci()
 
-    result <- gen_table("61111-0001", startyear = 2019)
+    result <- gen_table("61111-0001",
+                        startyear = 2019,
+                        database = "genesis")
 
     expect_s3_class(result,
                     class = "data.frame")
@@ -20,6 +22,7 @@ with_mock_dir("table1", {
     expect_true("spec" %in% names(attrs))
 
     })
+
 })
 
 #-------------------------------------------------------------------------------
@@ -28,10 +31,10 @@ with_mock_dir("table1", {
 
 test_that("gen_table errors on wrong year parameters", {
 
-  expect_error(gen_table("61111-0004", startyear = 1893),
+  expect_error(gen_table("61111-0004", startyear = 1893, database = "genesis"),
                regexp = "The parameter 'year' has been misspecified")
 
-  expect_error(gen_table("61111-0004", startyear = "1893"),
+  expect_error(gen_table("61111-0004", startyear = "1893", database = "genesis"),
                regexp = "The parameter 'year' has been misspecified")
 
 })
